@@ -1,7 +1,26 @@
 ;;; reftex-vars.el - Configuration variables for RefTeX
-;;; Version: 4.9
-;;;
-;;; See main file reftex.el for licensing information
+;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
+
+;; Author:     Carsten Dominik <dominik@strw.LeidenUniv.nl>
+;; Version: 4.10
+;;
+
+;; This file is part of GNU Emacs.
+
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to the
+;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+;; Boston, MA 02111-1307, USA.
 
 (eval-when-compile (require 'cl))
 (provide 'reftex-vars)
@@ -1107,6 +1126,12 @@ Requires the `texmathp.el' library which is part of AUCTeX."
   :group 'reftex-index-support
   :type 'string)
 
+(defcustom reftex-index-phrase-file-extension ".rip"
+  "File extension for the index phrase file.
+This extension will be added to the base name of the master file."
+  :group 'reftex-index-support
+  :type 'string)
+
 (defcustom reftex-index-phrases-logical-and-regexp " *&& *"
   "Regexp matching the `and' operator for index arguments in phrases file.
 When several index arguments in a phrase line are separated by this
@@ -1440,6 +1465,12 @@ information.  When this variable is t,
   :group 'reftex-optimizations-for-large-documents
   :type 'boolean)
 
+(defcustom reftex-parse-file-extension ".rel"
+  "*File extension for the file in which parser information is stored.
+This extension is added to the base name of the master file."
+  :group 'reftex-optimizations-for-large-documents
+  :type 'string)
+
 (defcustom reftex-use-multiple-selection-buffers nil
   "*Non-nil means use a separate selection buffer for each label type.
 These buffers are kept from one selection to the next and need not to be
