@@ -1,11 +1,11 @@
 ;;; reftex.el --- Minor mode for doing \label, \ref, \cite, \index in LaTeX
-;; Copyright (c) 1997, 1998, 1999 Free Software Foundation, Inc.
+;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
 
 ;; Author:     Carsten Dominik <dominik@strw.LeidenUniv.nl>
-;; Version:    4.9
+;; Version:    4.10
 ;; Keywords:   tex
 
-;; This file is not part of GNU Emacs.
+;; This file is part of GNU Emacs.
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -300,7 +300,7 @@
 ;;; Define the formal stuff for a minor mode named RefTeX.
 ;;;
 
-(defconst reftex-version "RefTeX version 4.9"
+(defconst reftex-version "RefTeX version 4.10"
   "Version string for RefTeX.")
 
 (defvar reftex-mode nil
@@ -1224,8 +1224,9 @@ Valid actions are: readable, restore, read, kill, write."
          (master (reftex-TeX-master-file))
 	 (enable-local-variables nil)
          (file (if (string-match "\\.[a-zA-Z]+\\'" master)
-                   (concat (substring master 0 (match-beginning 0)) ".rel")
-                 (concat master ".rel"))))
+                   (concat (substring master 0 (match-beginning 0)) 
+			   reftex-parse-file-extension)
+                 (concat master reftex-parse-file-extension))))
     (cond
      ((eq action 'readable)
       (file-readable-p file))
@@ -1655,12 +1656,12 @@ When DIE is non-nil, throw an error if file not found."
 ;;;
 ;;; View cross references
 
-(autoload 'reftex-view-crossref "reftex-vcr"
+(autoload 'reftex-view-crossref "reftex-dcr"
  "View cross reference of \\ref or \\cite macro at point." t)
-(autoload 'reftex-mouse-view-crossref "reftex-vcr"
+(autoload 'reftex-mouse-view-crossref "reftex-dcr"
  "View cross reference of \\ref or \\cite macro where you click." t)
-(autoload 'reftex-toggle-auto-view-crossref "reftex-vcr")
-(autoload 'reftex-view-crossref-from-bibtex "reftex-vcr"
+(autoload 'reftex-toggle-auto-view-crossref "reftex-dcr")
+(autoload 'reftex-view-crossref-from-bibtex "reftex-dcr"
  "View location in a LaTeX document which cites the BibTeX entry at point." t)
 
 
